"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: EventFunctions.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


def EVT_ACTIVATE(win, func):
    """"""
    pass

def EVT_ACTIVATE_APP(win, func):
    """"""
    pass

def EVT_BUTTON(win, id, func):
    """"""
    pass

def EVT_CALCULATE_LAYOUT():
    """"""
    pass

def EVT_CHAR(win, func):
    """"""
    pass

def EVT_CHAR_HOOK(win, func):
    """"""
    pass

def EVT_CHECKBOX(win, id, func):
    """"""
    pass

def EVT_CHECKLISTBOX(win, id, func):
    """"""
    pass

def EVT_CHILD_FOCUS(win, func):
    """"""
    pass

def EVT_CHOICE(win, id, func):
    """"""
    pass

def EVT_CLOSE(win, func):
    """"""
    pass

def EVT_COMBOBOX(win, id, func):
    """"""
    pass

def EVT_COMMAND(win, id, cmd, func):
    """"""
    pass

def EVT_COMMAND_ENTER(win, id, func):
    """"""
    pass

def EVT_COMMAND_FIND():
    """"""
    pass

def EVT_COMMAND_FIND_CLOSE():
    """"""
    pass

def EVT_COMMAND_FIND_NEXT():
    """"""
    pass

def EVT_COMMAND_FIND_REPLACE():
    """"""
    pass

def EVT_COMMAND_FIND_REPLACE_ALL():
    """"""
    pass

def EVT_COMMAND_KILL_FOCUS(win, id, func):
    """"""
    pass

def EVT_COMMAND_LEFT_CLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_LEFT_DCLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_RANGE(win, id1, id2, cmd, func):
    """"""
    pass

def EVT_COMMAND_RIGHT_CLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_RIGHT_DCLICK(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_BOTTOM(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_LINEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_LINEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_PAGEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_PAGEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_THUMBRELEASE(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_THUMBTRACK(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLLWIN_TOP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_BOTTOM(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_ENDSCROLL(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_LINEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_LINEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_PAGEDOWN(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_PAGEUP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_THUMBRELEASE(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_THUMBTRACK(win, id, func):
    """"""
    pass

def EVT_COMMAND_SCROLL_TOP(win, id, func):
    """"""
    pass

def EVT_COMMAND_SET_FOCUS(win, id, func):
    """"""
    pass

def EVT_CONTEXT_MENU(win, func):
    """"""
    pass

def EVT_DISPLAY_CHANGED(win, func):
    """"""
    pass

def EVT_DROP_FILES(win, func):
    """"""
    pass

def EVT_END_PROCESS(eh, id, func):
    """"""
    pass

def EVT_END_SESSION(win, func):
    """"""
    pass

def EVT_ENTER_WINDOW(win, func):
    """"""
    pass

def EVT_ERASE_BACKGROUND(win, func):
    """"""
    pass

def EVT_ICONIZE(win, func):
    """"""
    pass

def EVT_IDLE(win, func):
    """"""
    pass

def EVT_INIT_DIALOG(win, func):
    """"""
    pass

def EVT_JOYSTICK_EVENTS(win, func):
    """"""
    pass

def EVT_JOY_DOWN(win, func):
    """"""
    pass

def EVT_JOY_MOVE(win, func):
    """"""
    pass

def EVT_JOY_UP(win, func):
    """"""
    pass

def EVT_JOY_ZMOVE(win, func):
    """"""
    pass

def EVT_KEY_DOWN(win, func):
    """"""
    pass

def EVT_KEY_UP(win, func):
    """"""
    pass

def EVT_KILL_FOCUS(win, func):
    """"""
    pass

def EVT_LEAVE_WINDOW(win, func):
    """"""
    pass

def EVT_LEFT_DCLICK(win, func):
    """"""
    pass

def EVT_LEFT_DOWN(win, func):
    """"""
    pass

def EVT_LEFT_UP(win, func):
    """"""
    pass

def EVT_LISTBOX(win, id, func):
    """"""
    pass

def EVT_LISTBOX_DCLICK(win, id, func):
    """"""
    pass

def EVT_LIST_BEGIN_DRAG():
    """"""
    pass

def EVT_LIST_BEGIN_LABEL_EDIT():
    """"""
    pass

def EVT_LIST_BEGIN_RDRAG():
    """"""
    pass

def EVT_LIST_CACHE_HINT():
    """"""
    pass

def EVT_LIST_COL_BEGIN_DRAG():
    """"""
    pass

def EVT_LIST_COL_CLICK():
    """"""
    pass

def EVT_LIST_COL_DRAGGING():
    """"""
    pass

def EVT_LIST_COL_END_DRAG():
    """"""
    pass

def EVT_LIST_COL_RIGHT_CLICK():
    """"""
    pass

def EVT_LIST_DELETE_ALL_ITEMS():
    """"""
    pass

def EVT_LIST_DELETE_ITEM():
    """"""
    pass

def EVT_LIST_END_LABEL_EDIT():
    """"""
    pass

def EVT_LIST_GET_INFO():
    """"""
    pass

def EVT_LIST_INSERT_ITEM():
    """"""
    pass

def EVT_LIST_ITEM_ACTIVATED():
    """"""
    pass

def EVT_LIST_ITEM_DESELECTED():
    """"""
    pass

def EVT_LIST_ITEM_FOCUSED():
    """"""
    pass

def EVT_LIST_ITEM_MIDDLE_CLICK():
    """"""
    pass

def EVT_LIST_ITEM_RIGHT_CLICK():
    """"""
    pass

def EVT_LIST_ITEM_SELECTED():
    """"""
    pass

def EVT_LIST_KEY_DOWN():
    """"""
    pass

def EVT_LIST_SET_INFO():
    """"""
    pass

def EVT_MAXIMIZE(win, func):
    """"""
    pass

def EVT_MENU(win, id, func):
    """"""
    pass

def EVT_MENU_CLOSE(win, func):
    """"""
    pass

def EVT_MENU_HIGHLIGHT(win, id, func):
    """"""
    pass

def EVT_MENU_HIGHLIGHT_ALL(win, func):
    """"""
    pass

def EVT_MENU_OPEN(win, func):
    """"""
    pass

def EVT_MENU_RANGE(win, id1, id2, func):
    """"""
    pass

def EVT_MIDDLE_DCLICK(win, func):
    """"""
    pass

def EVT_MIDDLE_DOWN(win, func):
    """"""
    pass

def EVT_MIDDLE_UP(win, func):
    """"""
    pass

def EVT_MOTION(win, func):
    """"""
    pass

def EVT_MOUSEWHEEL(win, func):
    """"""
    pass

def EVT_MOUSE_CAPTURE_CHANGED(win, func):
    """"""
    pass

def EVT_MOUSE_EVENTS(win, func):
    """"""
    pass

def EVT_MOVE(win, func):
    """"""
    pass

def EVT_NAVIGATION_KEY(win, func):
    """"""
    pass

def EVT_NOTEBOOK_PAGE_CHANGED(win, id, func):
    """"""
    pass

def EVT_NOTEBOOK_PAGE_CHANGING(win, id, func):
    """"""
    pass

def EVT_PAINT(win, func):
    """"""
    pass

def EVT_PALETTE_CHANGED(win, func):
    """"""
    pass

def EVT_QUERY_END_SESSION(win, func):
    """"""
    pass

def EVT_QUERY_LAYOUT_INFO():
    """"""
    pass

def EVT_QUERY_NEW_PALETTE(win, func):
    """"""
    pass

def EVT_RADIOBOX(win, id, func):
    """"""
    pass

def EVT_RADIOBUTTON(win, id, func):
    """"""
    pass

def EVT_RIGHT_DCLICK(win, func):
    """"""
    pass

def EVT_RIGHT_DOWN(win, func):
    """"""
    pass

def EVT_RIGHT_UP(win, func):
    """"""
    pass

def EVT_SASH_DRAGGED(win, id, func):
    """"""
    pass

def EVT_SASH_DRAGGED_RANGE(win, id1, id2, func):
    """"""
    pass

def EVT_SCROLL(win, func):
    """"""
    pass

def EVT_SCROLLWIN(win, func):
    """"""
    pass

def EVT_SCROLLWIN_BOTTOM(win, func):
    """"""
    pass

def EVT_SCROLLWIN_LINEDOWN(win, func):
    """"""
    pass

def EVT_SCROLLWIN_LINEUP(win, func):
    """"""
    pass

def EVT_SCROLLWIN_PAGEDOWN(win, func):
    """"""
    pass

def EVT_SCROLLWIN_PAGEUP(win, func):
    """"""
    pass

def EVT_SCROLLWIN_THUMBRELEASE(win, func):
    """"""
    pass

def EVT_SCROLLWIN_THUMBTRACK(win, func):
    """"""
    pass

def EVT_SCROLLWIN_TOP(win, func):
    """"""
    pass

def EVT_SCROLL_BOTTOM(win, func):
    """"""
    pass

def EVT_SCROLL_ENDSCROLL(win, func):
    """"""
    pass

def EVT_SCROLL_LINEDOWN(win, func):
    """"""
    pass

def EVT_SCROLL_LINEUP(win, func):
    """"""
    pass

def EVT_SCROLL_PAGEDOWN(win, func):
    """"""
    pass

def EVT_SCROLL_PAGEUP(win, func):
    """"""
    pass

def EVT_SCROLL_THUMBRELEASE(win, func):
    """"""
    pass

def EVT_SCROLL_THUMBTRACK(win, func):
    """"""
    pass

def EVT_SCROLL_TOP(win, func):
    """"""
    pass

def EVT_SET_CURSOR(win, func):
    """"""
    pass

def EVT_SET_FOCUS(win, func):
    """"""
    pass

def EVT_SHOW(win, func):
    """"""
    pass

def EVT_SIZE():
    """"""
    pass

def EVT_SLIDER(win, id, func):
    """"""
    pass

def EVT_SPIN(win, id, func):
    """"""
    pass

def EVT_SPINCTRL(win, id, func):
    """"""
    pass

def EVT_SPIN_DOWN(win, id, func):
    """"""
    pass

def EVT_SPIN_UP(win, id, func):
    """"""
    pass

def EVT_SPLITTER_DOUBLECLICKED(win, id, func):
    """"""
    pass

def EVT_SPLITTER_SASH_POS_CHANGED(win, id, func):
    """"""
    pass

def EVT_SPLITTER_SASH_POS_CHANGING(win, id, func):
    """"""
    pass

def EVT_SPLITTER_UNSPLIT(win, id, func):
    """"""
    pass

def EVT_SYS_COLOUR_CHANGED(win, func):
    """"""
    pass

def EVT_TASKBAR_LEFT_DCLICK(win, func):
    """"""
    pass

def EVT_TASKBAR_LEFT_DOWN(win, func):
    """"""
    pass

def EVT_TASKBAR_LEFT_UP(win, func):
    """"""
    pass

def EVT_TASKBAR_MOVE(win, func):
    """"""
    pass

def EVT_TASKBAR_RIGHT_DCLICK(win, func):
    """"""
    pass

def EVT_TASKBAR_RIGHT_DOWN(win, func):
    """"""
    pass

def EVT_TASKBAR_RIGHT_UP(win, func):
    """"""
    pass

def EVT_TEXT(win, id, func):
    """"""
    pass

def EVT_TEXT_ENTER(win, id, func):
    """"""
    pass

def EVT_TEXT_MAXLEN(win, id, func):
    """"""
    pass

def EVT_TEXT_URL(win, id, func):
    """"""
    pass

def EVT_TIMER(win, id, func):
    """"""
    pass

def EVT_TOGGLEBUTTON(win, id, func):
    """"""
    pass

def EVT_TOOL(win, id, func):
    """"""
    pass

def EVT_TOOL_ENTER(win, id, func):
    """"""
    pass

def EVT_TOOL_RANGE(win, id, id2, func):
    """"""
    pass

def EVT_TOOL_RCLICKED(win, id, func):
    """"""
    pass

def EVT_TOOL_RCLICKED_RANGE(win, id, id2, func):
    """"""
    pass

def EVT_TREE_BEGIN_DRAG():
    """"""
    pass

def EVT_TREE_BEGIN_LABEL_EDIT():
    """"""
    pass

def EVT_TREE_BEGIN_RDRAG():
    """"""
    pass

def EVT_TREE_DELETE_ITEM():
    """"""
    pass

def EVT_TREE_END_DRAG():
    """"""
    pass

def EVT_TREE_END_LABEL_EDIT():
    """"""
    pass

def EVT_TREE_GET_INFO():
    """"""
    pass

def EVT_TREE_ITEM_ACTIVATED():
    """"""
    pass

def EVT_TREE_ITEM_COLLAPSED():
    """"""
    pass

def EVT_TREE_ITEM_COLLAPSING():
    """"""
    pass

def EVT_TREE_ITEM_EXPANDED():
    """"""
    pass

def EVT_TREE_ITEM_EXPANDING():
    """"""
    pass

def EVT_TREE_ITEM_MIDDLE_CLICK():
    """"""
    pass

def EVT_TREE_ITEM_RIGHT_CLICK():
    """"""
    pass

def EVT_TREE_KEY_DOWN():
    """"""
    pass

def EVT_TREE_SEL_CHANGED():
    """"""
    pass

def EVT_TREE_SEL_CHANGING():
    """"""
    pass

def EVT_TREE_SET_INFO():
    """"""
    pass

def EVT_UPDATE_UI(win, id, func):
    """"""
    pass

def EVT_UPDATE_UI_RANGE(win, id, id2, func):
    """"""
    pass

def EVT_VLBOX(win, id, func):
    """"""
    pass

def EVT_WINDOW_CREATE(win, func):
    """"""
    pass

def EVT_WINDOW_DESTROY(win, func):
    """"""
    pass

